#
# spec file for package wpebackend-fdo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1

Name:           wpebackend-fdo
Version:        1.14.2
Release:        1.3
Summary:        A WPE backend designed for Linux desktop systems
License:        BSD-2-Clause
URL:            https://github.com/Igalia/WPEBackend-fdo
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source99:       baselibs.conf

BuildRequires:  c++_compiler
BuildRequires:  meson >= 0.49
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(wpe-1.0) >= 1.6.0
BuildRequires:  pkgconfig(xkbcommon)

%description
A WPE backend designed for Linux desktop systems.

%package -n     libWPEBackend-fdo-1_0-%{sover}
Summary:        Shared library for wpebackend-fdo

%description -n libWPEBackend-fdo-1_0-%{sover}
A WPE backend designed for Linux desktop systems.

This package contains the shared library.

%package        devel
Summary:        Development files for %{name}
Requires:       libWPEBackend-fdo-1_0-%{sover} = %{version}

%description    devel
The %{name}-devel package contains libraries, build data, and
header files for developing applications that use %{name}.

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n libWPEBackend-fdo-1_0-%{sover}

%files -n libWPEBackend-fdo-1_0-%{sover}
%license COPYING
%doc NEWS
%{_libdir}/libWPEBackend-fdo-1.0.so.*

%files devel
%{_includedir}/wpe-fdo-1.0
%{_libdir}/libWPEBackend-fdo-1.0.so
%{_libdir}/pkgconfig/%{name}-1.0.pc

%changelog
* Wed Aug  2 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Update to version 1.14.2
  + Reverted a change introduced in 1.14.1 which introduced crashes
    both with WebKitGTK and WPE running under Wayland in some
    configurations.
  + Fix a crash caused by wrong assertion, which was typically
    triggered in debug builds when using the NVidia drivers.
- Update to version 1.14.1:
  + Fix WebKit no longer repainting after provisional navigation
    wit PSON enabled.
  + Fix graphics buffer leaks by always freeing them in buffer
    destroy listener callbacks.
* Tue Oct  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.0:
  + Fixed a crash caused by trying to deallocate already freed
    graphics buffers in certain situations.
- Use ldconfig_scriptlets macro for post(un) handling.
* Fri Aug 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.12.1:
  + Fixed a crash caused by trying to deallocate already freed
    graphics buffers in certain situations.
* Thu Nov 25 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.12.0:
  + Added API to obtain the wl_resource for SHM exported buffers.
  + Added unstable DMA-BUF pool API for buffer management.
  + Fixed UI process getting stuck when navigating across different
    security origins.
  + Fixed invalid usage of Wayland client connections in the nested
    compositor which caused crashes in some situations.
  + Made it easier to override where Meson looks for
    wayland-scanner during cross-compilation, using a native
    machine file.
* Fri Sep 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.10.0:
  + Added API to query whether receiving rendered audio has been
    configured.
  + Added API to obtain the wl_resource for SHM exported buffers.
  + The CMake build system has been removed in favor of Meson.
  + Made it easier to override where Meson looks for
    wayland-scanner during cross-compilation, using a native
    machine file.
  + Fixed invalid usage of Wayland client connections in the nested
    compositor which caused sporadic crashes in certain conditions.
  + Fixed file descriptor and memory leaks.
* Thu Sep 17 2020 Michael Gorse <mgorse@suse.com>
- Update to version 1.8.0:
  + Added new API for the audio rendering protocol, which allows
    embedders to receive audio samples instead of letting WPE
    WebKit handle their playback.
  + Added support to export frames using EGLStreams, which can be
    used e.g.  with Nvidia GPUs.
  + New build configuration system based on Meson. The existing
    CMake-based system is still maintained, and both produce the
    same outputs.
  + Use libepoxy for EGL operations.
- Switch to meson.
- Add epoxy to BuildRequires: new dependency.
* Wed Jun 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.1:
  + Fixed build when using EGL stacks with odd EGLNativeDisplay
    definitions.
  + Fixed version retrieval functions not being exposed as public
    symbols.
  + Improve build configuration by instructing CMake to report
    mismatched versions of dependency libraries, instead of failing
    to compile.
* Thu Mar 12 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.0:
  + Added support for the DMA-BUF video plane display protocol.
  + Added support for exporting DMA-BUF buffers.
  + Added support for exporting SHM-based buffers.
  + Fix building the documentation.
  + Ensure that only symbols marked as public are exported.
- Add explicit pkgconfig(wayland-client) and
  pkgconfig(wayland-server) BuildRequires: cmake checks for them.
- Pass explicit -DWayland_VERSION_HEADER_PATH=$(pkg-config
  - -variable=includedir wayland-client) to cmake, let cmake find
  our wayland headers properly.
* Thu Mar 12 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.4.2:
  + Fix build failures with EGL implementations which do not
    provide an EGL/eglmesaext.h header.
* Tue Feb 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.4.1 (boo#1164688):
  + Fix build failures with recent compiler versions due to missing
    function declarations.
- Drop memset-prototype.patch: fixed upstream.
* Mon Oct  7 2019 Michael Gorse <mgorse@suse.com>
- Add memset-prototype.patch: fix usage of undeclared
  std::memset() function.
* Sat Oct  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add baselibs.conf, build 32-bit support libs.
- Drop Group tag added by mistake.
* Thu Sep 19 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.4.0:
  + New macros in the API to check the version at compilation
    time.
  + New API for exported images which allows querying their
    dimension their backing EGLImageKHR.
  + Support DMA-BUF resource exports through a new callback in the
    API.
  + Added support for detaching and attaching new targets to a view
    backend.
  + Improved management and cleanup of Wayland resources.
  + Improved handling of Wayland events.
  + Build system improvements.
* Tue Sep 17 2019 Michael Gorse <mgorse@suse.com>
- Update to version 1.3.91:
  + Support DMA-BUF resource exports through a new callback in the
    API.
  + Improve management and cleanup of Wayland resources.
  + Make the build more reliable using CMake imported library
    targets.
  + Enable compiler warnings.
- Drop wpebackend-fdo-fix-include-dirs.patch: fixed upstream.
* Thu Jul 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Initial package for openSUSE, version 1.3.1.
